@@ -110,6 +110,21 @@ class JobCacheStrategy(Enum):
     data_hash = "data_hash"
 
 
+class KiaraSettings(BaseSettings):
+    class Config:
+        extra = Extra.forbid
+        validate_assignment = True
+        env_prefix = "kiara_setting_"
+
+    syntax_highlight_background: str = Field(
+        description="The background color for code blocks when rendering to terminal, Jupyter, etc.",
+        default="default",
+    )
+
+
+KIARA_SETTINGS = KiaraSettings()
+
+
 class KiaraRuntimeConfig(BaseSettings):
     class Config:
         extra = Extra.forbid
@@ -131,14 +146,6 @@ class KiaraConfig(BaseSettings):
         env_prefix = "kiara_"
         extra = Extra.forbid
         use_enum_values = True
-        # @classmethod
-        # def customise_sources(
-        #     cls,
-        #     init_settings,
-        #     env_settings,
-        #     file_secret_settings,
-        # ):
-        #     return (init_settings, env_settings, config_file_settings_source)
 
     @classmethod
     def create_in_folder(cls, path: Union[Path, str]) -> "KiaraConfig":
@@ -151,7 +158,7 @@ class KiaraConfig(BaseSettings):
                 f"Can't create new kiara config, path exists: {path.as_posix()}"
             )
 
-        config = KiaraConfig(base_data_path=path)
+        config = KiaraConfig(base_data_path=path.as_posix())
         config_file = path / KIARA_CONFIG_FILE_NAME
 
         config.save(config_file)
@@ -320,7 +327,10 @@ class KiaraConfig(BaseSettings):
     def _validate_context(self, context_config: KiaraContextConfig) -> bool:
 
         env_registry = EnvironmentRegistry.instance()
-        available_archives = env_registry.environments["kiara_types"].archive_types
+        from kiara.models.runtime_environment.kiara import KiaraTypesRuntimeEnvironment
+
+        kiara_types: KiaraTypesRuntimeEnvironment = env_registry.environments["kiara_types"]  # type: ignore
+        available_archives = kiara_types.archive_types
 
         changed = False
         if DEFAULT_DATA_STORE_MARKER not in context_config.archives.keys():
