@@ -24,28 +24,17 @@ be discouraged, since this might not be trivial and there are quite a few things
 
 """
 import abc
-import copy
 import orjson
 import structlog
 import uuid
 from deepdiff import DeepHash
-from pydantic import BaseModel, Extra, Field, PrivateAttr, ValidationError
+from pydantic import BaseModel, Extra, PrivateAttr, ValidationError
 from rich import box
 from rich.console import Console, ConsoleOptions, RenderResult
 from rich.rule import Rule
 from rich.syntax import Syntax
 from rich.table import Table
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Generic,
-    Mapping,
-    Optional,
-    Tuple,
-    Type,
-    TypeVar,
-    Union,
-)
+from typing import TYPE_CHECKING, Any, Generic, Mapping, Tuple, Type, TypeVar, Union
 
 from kiara.defaults import (
     INVALID_HASH_MARKER,
@@ -56,7 +45,7 @@ from kiara.defaults import (
 )
 from kiara.exceptions import KiaraValueException, ValueTypeConfigException
 from kiara.models.python_class import PythonClass
-from kiara.models.values import ValueStatus
+from kiara.models.values import DataTypeCharacteristics, ValueStatus
 from kiara.models.values.value_schema import ValueSchema
 
 #
@@ -64,11 +53,15 @@ from kiara.models.values.value_schema import ValueSchema
 #         return obj.__class__.__name__
 #     else:
 #         return f"{obj.__class__.__module__}.{obj.__class__.__name__}"
-from kiara.utils import orjson_dumps
+from kiara.utils.json import orjson_dumps
 
 if TYPE_CHECKING:
-    from kiara.models.values.value import SerializedData, Value, ValuePedigree
-
+    from kiara.models.values.value import (
+        DataTypeInfo,
+        SerializedData,
+        Value,
+        ValuePedigree,
+    )
 
 logger = structlog.getLogger()
 
@@ -97,7 +90,7 @@ class DataTypeConfig(BaseModel):
                 return True
         return False
 
-    _config_hash: Optional[int] = PrivateAttr(default=None)
+    _config_hash: Union[int, None] = PrivateAttr(default=None)
 
     def get(self, key: str) -> Any:
         """Get the value for the specified configuation key."""
@@ -146,18 +139,6 @@ TYPE_PYTHON_CLS = TypeVar("TYPE_PYTHON_CLS")
 TYPE_CONFIG_CLS = TypeVar("TYPE_CONFIG_CLS", bound=DataTypeConfig)
 
 
-class DataTypeCharacteristics(BaseModel):
-
-    is_scalar: bool = Field(
-        description="Whether the data desribed by this data type behaves like a skalar.",
-        default=False,
-    )
-    is_json_serializable: bool = Field(
-        description="Whether the data can be serialized to json without information loss.",
-        default=False,
-    )
-
-
 class DataType(abc.ABC, Generic[TYPE_PYTHON_CLS, TYPE_CONFIG_CLS]):
     """Base class that all *kiara* data_types must inherit from.
 
@@ -216,8 +197,9 @@ class DataType(abc.ABC, Generic[TYPE_PYTHON_CLS, TYPE_CONFIG_CLS]):
                 ve,
             )
 
-        self._data_type_hash: Optional[int] = None
-        self._characteristics: Optional[DataTypeCharacteristics] = None
+        self._data_type_hash: Union[int, None] = None
+        self._characteristics: Union[DataTypeCharacteristics, None] = None
+        self._info: Union[DataTypeInfo, None] = None
 
     @property
     def data_type_name(self) -> str:
@@ -231,6 +213,23 @@ class DataType(abc.ABC, Generic[TYPE_PYTHON_CLS, TYPE_CONFIG_CLS]):
             )
         return self._data_type_hash
 
+    @property
+    def info(self) -> "DataTypeInfo":
+
+        if self._info is not None:
+            return self._info
+
+        from kiara.models.values.value import DataTypeInfo
+
+        self._info = DataTypeInfo(
+            data_type_name=self.data_type_name,
+            data_type_config=self.type_config.dict(),
+            characteristics=self.characteristics,
+            data_type_class=PythonClass.from_class(self.__class__),
+        )
+        self._info._data_type_instance = self
+        return self._info
+
     @property
     def characteristics(self) -> DataTypeCharacteristics:
         if self._characteristics is not None:
@@ -331,35 +330,36 @@ class DataType(abc.ABC, Generic[TYPE_PYTHON_CLS, TYPE_CONFIG_CLS]):
         self, data: Any, schema: ValueSchema
     ) -> Tuple[Any, Union[str, "SerializedData"], ValueStatus, str, int]:
 
+        assert data is not None
+
         if data is SpecialValue.NOT_SET:
             status = ValueStatus.NOT_SET
             data = None
+        elif data is SpecialValue.NO_VALUE:
+            status = ValueStatus.NONE
+            data = None
         else:
             status = ValueStatus.SET
 
-        if data is None and schema.default not in [
-            None,
-            SpecialValue.NO_VALUE,
-            SpecialValue.NOT_SET,
-        ]:
+        # if data is None and schema.default not in [
+        #     None,
+        #     SpecialValue.NO_VALUE,
+        #     SpecialValue.NOT_SET,
+        # ]:
+        #
+        #     status = ValueStatus.DEFAULT
+        #     if callable(schema.default):
+        #         data = schema.default()
+        #     else:
+        #         data = copy.deepcopy(schema.default)
 
-            status = ValueStatus.DEFAULT
-            if callable(schema.default):
-                data = schema.default()
-            else:
-                data = copy.deepcopy(schema.default)
-
-        if (
-            data is None
-            or data is SpecialValue.NO_VALUE
-            or data is SpecialValue.NOT_SET
-        ):
-            if schema.default in [None, SpecialValue.NO_VALUE]:
-                data = SpecialValue.NO_VALUE
-                status = ValueStatus.NONE
-            elif schema.default == SpecialValue.NOT_SET:
-                data = SpecialValue.NOT_SET
-                status = ValueStatus.NOT_SET
+        if data is None or data is SpecialValue.NOT_SET:
+            # if schema.default in [None, SpecialValue.NO_VALUE]:
+            #     data = SpecialValue.NO_VALUE
+            #     status = ValueStatus.NONE
+            # elif schema.default == SpecialValue.NOT_SET:
+            #     data = SpecialValue.NOT_SET
+            #     status = ValueStatus.NOT_SET
 
             size = 0
             value_hash = INVALID_HASH_MARKER
@@ -422,7 +422,6 @@ class DataType(abc.ABC, Generic[TYPE_PYTHON_CLS, TYPE_CONFIG_CLS]):
         if isinstance(status, str):
             status = ValueStatus(status).name
 
-        this_cls = PythonClass.from_class(self.__class__)
         if status in [ValueStatus.SET, ValueStatus.DEFAULT]:
             try:
 
@@ -436,7 +435,7 @@ class DataType(abc.ABC, Generic[TYPE_PYTHON_CLS, TYPE_CONFIG_CLS]):
                     environment_hashes=environment_hashes,
                     pedigree=pedigree,
                     pedigree_output_name=pedigree_output_name,
-                    data_type_class=this_cls,
+                    data_type_info=self.info,
                 )
 
             except Exception as e:
@@ -454,11 +453,10 @@ class DataType(abc.ABC, Generic[TYPE_PYTHON_CLS, TYPE_CONFIG_CLS]):
                 environment_hashes=environment_hashes,
                 pedigree=pedigree,
                 pedigree_output_name=pedigree_output_name,
-                data_type_class=this_cls,
+                data_type_info=self.info,
             )
 
         value._value_data = data
-        value._data_type = self
         value._serialized_data = serialized
         return value, data
 
@@ -501,7 +499,7 @@ class DataType(abc.ABC, Generic[TYPE_PYTHON_CLS, TYPE_CONFIG_CLS]):
         table.add_row("type_config", config)
 
         if show_type_info:
-            from kiara.models.values.data_type import DataTypeClassInfo
+            from kiara.interfaces.python_api.models.info import DataTypeClassInfo
 
             info = DataTypeClassInfo.create_from_type_class(self.__class__)
             table.add_row("", "")
