@@ -8,7 +8,7 @@ import orjson.orjson
 import structlog
 from pydantic import Field
 from rich.console import Group
-from typing import TYPE_CHECKING, Any, Dict, Mapping, Optional, Type
+from typing import TYPE_CHECKING, Any, Dict, Mapping, Type, Union
 
 from kiara.data_types import DataTypeConfig
 from kiara.data_types.included_core_types import AnyType, KiaraModelValueType
@@ -23,7 +23,7 @@ logger = structlog.getLogger()
 
 class FileTypeConfig(DataTypeConfig):
 
-    content_type: Optional[str] = Field(
+    content_type: Union[str, None] = Field(
         description="The content type of this file.", default=None
     )
 
@@ -103,7 +103,7 @@ class FileValueType(KiaraModelValueType[FileModel, FileTypeConfig]):
         else:
             raise Exception(f"Can't create FileModel from data of type '{type(data)}'.")
 
-    def pretty_print_as__string(
+    def _pretty_print_as__string(
         self, value: "Value", render_config: Mapping[str, Any]
     ) -> Any:
 
@@ -132,11 +132,11 @@ class FileValueType(KiaraModelValueType[FileModel, FileTypeConfig]):
             ]
             return "\n".join("lines")
 
-    def pretty_print_as__terminal_renderable(
+    def _pretty_print_as__terminal_renderable(
         self, value: "Value", render_config: Mapping[str, Any]
     ) -> Any:
 
-        data: Any = value.data
+        data: FileModel = value.data
         max_lines = render_config.get("max_lines", 34)
         try:
             lines = []
@@ -242,7 +242,7 @@ class FileBundleValueType(AnyType[FileBundle, FileTypeConfig]):
                 f"Can't create FileBundle from data of type '{type(data)}'."
             )
 
-    def pretty_print_as__terminal_renderable(
+    def _pretty_print_as__terminal_renderable(
         self, value: "Value", render_config: Mapping[str, Any]
     ) -> Any:
 
