@@ -9,19 +9,16 @@
 import rich_click as click
 import structlog
 import sys
-from typing import Iterable, Tuple, Union
+from typing import Iterable, Tuple
 
 from kiara.context import Kiara
 from kiara.interfaces.python_api import KiaraAPI
 from kiara.interfaces.python_api.models.info import RENDER_FIELDS, ValueInfo, ValuesInfo
 from kiara.interfaces.tui.pager import PagerApp
-from kiara.models.module.operation import Operation
 from kiara.operations.included_core_operations.filter import FilterOperationType
-from kiara.operations.included_core_operations.render_value import (
-    RenderValueOperationType,
-)
 from kiara.utils import log_exception, log_message
 from kiara.utils.cli import output_format_option, terminal_print, terminal_print_model
+from kiara.utils.cli.rich_click import rich_format_filter_operation_help
 from kiara.utils.cli.run import (
     _validate_save_option,
     calculate_aliases,
@@ -125,7 +122,7 @@ def list_values(
     properties,
     data_type,
     lineage,
-):
+) -> None:
     """List all data items that are stored in kiara."""
 
     kiara_api: KiaraAPI = ctx.obj["kiara_api"]
@@ -306,15 +303,7 @@ def load_value(ctx, value: str, single_page: bool):
         terminal_print(f"[red]Error[/red]: No value found for: {value}")
         sys.exit(1)
 
-    render_op: Union[Operation, None] = None
-    if not single_page:
-        render_value_op_type: RenderValueOperationType = kiara_api.get_operation_type(
-            op_type=RenderValueOperationType
-        )
-        render_op = render_value_op_type.get_render_operation(
-            source_type=_value.data_type_name, target_type="terminal_renderable"
-        )
-    else:
+    if single_page:
         logger.debug(
             "fallback.render_value",
             solution="use pretty print",
@@ -333,23 +322,14 @@ def load_value(ctx, value: str, single_page: bool):
 
         terminal_print(renderable)
         sys.exit(0)
-
-    # log_file = None
-    # if is_develop() or is_debug() or True:
-    #     log_file = "kiara_pager.log"
-    PagerApp.run(kiara_api=kiara_api, value=_value, operation=render_op)
-
-    # inputs = {
-    #     "value": _value,
-    #     "render_scene": {}
-    # }
-    # result = render_op.run(kiara=kiara_api.context, inputs=inputs)
-    # dbg(result["render_scene_result"].data)
+    else:
+        app = PagerApp(api=kiara_api, value=str(_value.value_id))
+        app.run()
 
 
 @data.command("filter")
-@click.argument("value", nargs=1, required=True)
-@click.argument("filters", nargs=1)
+@click.argument("value", nargs=1, required=True, default="__no_value__")
+@click.argument("filters", nargs=1, default="__no_filters__")
 @click.argument("inputs", nargs=-1, required=False)
 @click.option(
     "--explain",
@@ -379,7 +359,10 @@ def filter_value(
     save: Iterable[str],
     help: bool,
 ):
-    """Load a value, fiter it, then display."""
+    """Filter a value, then display it like the 'load' subcommand does.
+
+    Filters must be provided as a single string, where filters are seperated using ":".
+    """
 
     save_results = _validate_save_option(save)
 
@@ -389,6 +372,24 @@ def filter_value(
         silent = True
 
     kiara_obj: Kiara = ctx.obj["kiara"]
+    api: KiaraAPI = ctx.obj["kiara_api"]
+
+    cmd_help = "[yellow bold]Usage: [/yellow bold][bold]kiara data filter VALUE FILTER_1:FILTER_2 [FILTER ARGS...][/bold]"
+
+    if help and value == "__no_value__":
+        rich_format_filter_operation_help(
+            api=api,
+            obj=ctx.command,
+            ctx=ctx,
+            cmd_help=cmd_help,
+        )
+        sys.exit(0)
+
+    if filters == "__no_filters__":
+        rich_format_filter_operation_help(
+            api=api, obj=ctx.command, ctx=ctx, cmd_help=cmd_help, value=value
+        )
+        sys.exit(0)
 
     try:
         _value = kiara_obj.data_registry.get_value(value=value)
@@ -400,12 +401,12 @@ def filter_value(
         terminal_print(f"[red]Error[/red]: No value found for: {value}")
         sys.exit(1)
 
-    filter_op_type: FilterOperationType = kiara_obj.operation_registry.get_operation_type("filter")  # type: ignore
-
-    _filter_names = filters.split(",")
+    _filter_names = filters.split(":")
     filter_names = []
     for fn in _filter_names:
         filter_names.extend(fn.split(":"))
+
+    filter_op_type: FilterOperationType = kiara_obj.operation_registry.get_operation_type("filter")  # type: ignore
     op = filter_op_type.create_filter_operation(
         data_type=_value.data_type_name, filters=filter_names
     )
@@ -413,8 +414,6 @@ def filter_value(
     all_inputs = [f"value={value}"]
     all_inputs.extend(inputs)
 
-    cmd_help = "[yellow bold]Usage: [/yellow bold][bold]kiara data filter VALUE FILTER_1:FILTER_2 [FILTER ARGS...][/bold]"
-
     kiara_op = validate_operation_in_terminal(
         kiara=kiara_obj, module_or_operation="pipeline", module_config=op.module_config
     )
@@ -427,9 +426,38 @@ def filter_value(
         click_context=ctx,
         cmd_help=cmd_help,
     )
-    execute_job(
+    job_id = execute_job(
         kiara_op=kiara_op,
-        silent=silent,
-        save_results=save_results,
+        silent=True,
+        save_results=False,
         aliases=final_aliases,
     )
+
+    if not silent:
+        result = kiara_op.retrieve_result(job_id=job_id)
+        title = f"[b]Value '[i]{value}[/i]'[/b], filtered with: {filters}"
+        filtered = result["filtered_value"]
+        try:
+            renderable = api.context.data_registry.pretty_print_data(
+                filtered.value_id, target_type="terminal_renderable"
+            )
+        except Exception as e:
+            log_exception(e)
+            log_message("error.pretty_print", value=_value.value_id, error=e)
+            renderable = [str(_value.data)]
+        terminal_print(
+            renderable, in_panel=title, empty_line_before=True, show_data_type=True
+        )
+
+    if save_results:
+        try:
+            saved_results = kiara_op.save_result(job_id=job_id, aliases=final_aliases)
+            if len(saved_results) == 1:
+                title = "[b]Stored result value[/b]"
+            else:
+                title = "[b]Stored result values[/b]"
+            terminal_print(saved_results, in_panel=title, empty_line_before=True)
+        except Exception as e:
+            log_exception(e)
+            terminal_print(f"[red]Error saving results[/red]: {e}")
+            sys.exit(1)
