@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+import json
 
 #  Copyright (c) 2021, Markus Binsteiner
 #
@@ -6,14 +7,16 @@
 import structlog
 import uuid
 from pathlib import Path
+from ruamel.yaml import YAML
 from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Type, Union
 
-from kiara.exceptions import NoSuchWorkflowException
+from kiara.exceptions import DataTypeUnknownException, NoSuchWorkflowException
 from kiara.interfaces.python_api.models.info import (
     ModuleTypeInfo,
     ModuleTypesInfo,
     OperationGroupInfo,
     OperationInfo,
+    OperationTypeInfo,
     ValueInfo,
     ValuesInfo,
 )
@@ -28,6 +31,7 @@ from kiara.models.rendering import RenderValueResult
 from kiara.models.values.matchers import ValueMatcher
 from kiara.models.values.value import PersistedData, Value, ValueMap
 from kiara.models.workflow import WorkflowGroupInfo, WorkflowInfo, WorkflowMetadata
+from kiara.operations import OperationType
 from kiara.operations.included_core_operations.filter import FilterOperationType
 from kiara.operations.included_core_operations.pipeline import PipelineOperationDetails
 from kiara.operations.included_core_operations.render_value import (
@@ -36,13 +40,14 @@ from kiara.operations.included_core_operations.render_value import (
 from kiara.registries.data import ValueLink
 from kiara.registries.ids import ID_REGISTRY
 from kiara.registries.operations import OP_TYPE
-from kiara.utils import log_exception
+from kiara.utils import log_exception, log_message
 from kiara.utils.operations import create_operation
 
 if TYPE_CHECKING:
     from kiara.context import Kiara, KiaraRuntimeConfig
 
 logger = structlog.getLogger()
+yaml = YAML(typ="safe")
 
 
 class KiaraAPI(object):
@@ -59,7 +64,7 @@ class KiaraAPI(object):
     @classmethod
     def instance(
         cls,
-        context: Union["Kiara", str] = None,
+        context: Union["Kiara", str, None] = None,
         runtime_config: Union[None, Mapping[str, Any], "KiaraRuntimeConfig"] = None,
     ) -> "KiaraAPI":
 
@@ -97,6 +102,10 @@ class KiaraAPI(object):
         """
         return self._kiara
 
+    @property
+    def runtime_config(self) -> "KiaraRuntimeConfig":
+        return self.context.runtime_config
+
     # ==================================================================================================================
     # methods for module and operations info
     def retrieve_module_types_info(
@@ -161,7 +170,9 @@ class KiaraAPI(object):
         return info
 
     def create_operation(
-        self, module_type: str, module_config: Union[Mapping[str, Any], None] = None
+        self,
+        module_type: str,
+        module_config: Union[Mapping[str, Any], str, None] = None,
     ) -> Operation:
         """Create an [Operation][kiara.models.module.operation.Operation] instance for the specified module type and (optional) config.
 
@@ -177,11 +188,28 @@ class KiaraAPI(object):
 
         if module_config is None:
             module_config = {}
+        elif isinstance(module_config, str):
+            try:
+                module_config = json.load(module_config)  # type: ignore
+            except Exception:
+                try:
+                    module_config = yaml.load(module_config)  # type: ignore
+                except Exception:
+                    raise Exception(
+                        f"Can't parse module config string: {module_config}."
+                    )
 
-        mc = Manifest(module_type=module_type, module_config=module_config)
-        module_obj = self._kiara.create_module(mc)
+        if module_type == "pipeline":
+            if not module_config:
+                raise Exception("Pipeline configuration can't be empty.")
+            assert module_config is None or isinstance(module_config, Mapping)
+            operation = create_operation("pipeline", operation_config=module_config)
+            return operation
+        else:
+            mc = Manifest(module_type=module_type, module_config=module_config)
+            module_obj = self._kiara.create_module(mc)
 
-        return module_obj.operation
+            return module_obj.operation
 
     @property
     def operation_ids(self) -> List[str]:
@@ -579,11 +607,21 @@ class KiaraAPI(object):
     # ------------------------------------------------------------------------------------------------------------------
     # operation-related methods
 
-    def get_operation_type(self, op_type: Union[str, Type[OP_TYPE]]):
+    def get_operation_type(self, op_type: Union[str, Type[OP_TYPE]]) -> OperationType:
         """Get the management object for the specified operation type."""
 
         return self.context.operation_registry.get_operation_type(op_type=op_type)
 
+    def get_operation_type_info(
+        self, op_type: Union[str, Type[OP_TYPE]]
+    ) -> OperationTypeInfo:
+        """Get an info object for the specified operation type."""
+
+        _op_type = self.get_operation_type(op_type=op_type)
+        return OperationTypeInfo.create_from_type_class(
+            kiara=self.context, type_cls=_op_type.__class__
+        )
+
     # ------------------------------------------------------------------------------------------------------------------
     # pipeline-related methods
 
@@ -656,6 +694,9 @@ class KiaraAPI(object):
             "render_value"
         )  # type: ignore
 
+        if data_type not in self.context.data_type_names:
+            raise DataTypeUnknownException(data_type=data_type)
+
         ops = render_op_type.get_render_operations_for_source_type(data_type)
 
         if isinstance(target_format, str):
@@ -837,6 +878,7 @@ class KiaraAPI(object):
         target_format: Union[str, Iterable[str]] = "string",
         filters: Union[None, Iterable[str], Mapping[str, str]] = None,
         render_config: Union[Mapping[str, str], None] = None,
+        add_root_scenes: bool = True,
     ) -> RenderValueResult:
         """Render a value in the specified target format.
 
@@ -848,17 +890,34 @@ class KiaraAPI(object):
             target_format: the format into which to render the value
             filters: an (optional) list of filters
             render_config: manifest specific render configuration
+            add_root_scenes: add root scenes to the result
 
         Returns:
-            the rendered value data
+            the rendered value data, and any related scenes, if applicable
         """
 
         _value = self.get_value(value)
-        render_operation = self.assemble_render_pipeline(
-            data_type=_value.data_type_name,
-            target_format=target_format,
-            filters=filters,
-        )
+        try:
+            render_operation: Union[None, Operation] = self.assemble_render_pipeline(
+                data_type=_value.data_type_name,
+                target_format=target_format,
+                filters=filters,
+            )
+        except DataTypeUnknownException as dtue:
+            log_message("data_type.unknown", data_type=dtue.data_type, error=dtue)
+            render_ops: RenderValueOperationType = self.context.operation_registry.get_operation_type("render_value")  # type: ignore
+            if not isinstance(target_format, str):
+                raise NotImplementedError(
+                    "Can't handle multiple target formats for 'render_value' yet."
+                )
+            render_operation = render_ops.get_render_operation(
+                source_type="any", target_type=target_format
+            )
+
+        if render_operation is None:
+            raise Exception(
+                f"Could not find render operation for value: {_value.value_id}"
+            )
 
         if render_config and "render_config" in render_config.keys():
             # raise NotImplementedError()
@@ -871,18 +930,35 @@ class KiaraAPI(object):
             #     )
             # render_config = render_config["render_config"]
 
+        if render_config is None:
+            render_config = {}
+        else:
+            render_config = dict(render_config)
+
+        # render_type = render_config.pop("render_type", None)
+        # if not render_type or render_type == "data":
+        #     pass
+        # elif render_type == "metadata":
+        #     pass
+        # elif render_type == "properties":
+        #     pass
+        # elif render_type == "lineage":
+        #     pass
+
         result = render_operation.run(
             kiara=self.context,
             inputs={"value": _value, "render_config": render_config},
         )
 
-        render_result = result["render_value_result"]
+        render_result: Value = result["render_value_result"]
         if render_result.data_type_name != "render_value_result":
             raise Exception(
                 f"Invalid result type for render operation: {render_result.data_type_name}"
             )
 
-        return render_result.data
+        value_render_data: RenderValueResult = render_result.data  # type: ignore
+
+        return value_render_data
 
     # ------------------------------------------------------------------------------------------------------------------
     # workflow-related methods
@@ -1032,7 +1108,7 @@ class KiaraAPI(object):
         workflow_alias: Union[None, str] = None,
         initial_pipeline: Union[None, str] = None,
         initial_inputs: Union[None, Mapping[str, Any]] = None,
-        documentation: Any = None,
+        documentation: Union[Any, None] = None,
         save: bool = False,
         force_alias: bool = False,
     ) -> Workflow:
