@@ -4,19 +4,30 @@
 #
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
+import orjson
 import os
 from enum import Enum
 from pydantic import Extra, Field, PrivateAttr, root_validator, validator
+from rich import box
 from rich.console import RenderableType
+from rich.markdown import Markdown
+from rich.panel import Panel
+from rich.syntax import Syntax
+from rich.table import Table
 from slugify import slugify
-from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Optional
+from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Mapping, Union
 
-from kiara.models.module import KiaraModuleClass, KiaraModuleConfig
+from kiara.models.documentation import DocumentationMetadataModel
+from kiara.models.module import KiaraModuleConfig
 from kiara.models.module.jobs import ExecutionContext
 from kiara.models.module.manifest import Manifest
 from kiara.models.module.pipeline.value_refs import StepValueAddress
-from kiara.utils import get_data_from_file
-from kiara.utils.output import create_table_from_model_object
+from kiara.models.python_class import KiaraModuleInstance
+from kiara.utils import find_free_id, is_jupyter
+from kiara.utils.files import get_data_from_file
+from kiara.utils.json import orjson_dumps
+from kiara.utils.modules import module_config_is_empty
+from kiara.utils.output import create_table_from_field_schemas
 from kiara.utils.pipelines import ensure_step_value_addresses
 from kiara.utils.string_vars import replace_var_names_in_obj
 
@@ -44,28 +55,26 @@ class PipelineStep(Manifest):
         extra = Extra.forbid
 
     @classmethod
-    def create_steps(
+    def create_step(
         cls,
-        *steps: Mapping[str, Any],
+        step: Union["PipelineStep", Mapping[str, Any]],
         kiara: "Kiara",
-        module_map: Optional[Mapping[str, Any]] = None,
-    ) -> List["PipelineStep"]:
+        module_map: Union[Mapping[str, Any], None] = None,
+        auto_step_id: bool = False,
+        taken_step_ids: Union[List[str], None] = None,
+    ):
+        """Create a step object from step data.
+
+        Beware: the provided 'module_map' dictionary will be modified, as will the 'taken_step_ids'.
+        """
 
         if module_map is None:
             module_map = {}
-        else:
-            module_map = dict(module_map)
 
-        if kiara.operation_registry.is_initialized:
-            for op_id, op in kiara.operation_registry.operations.items():
-                module_map[op_id] = {
-                    "module_type": op.module_type,
-                    "module_config": op.module_config,
-                }
+        if taken_step_ids is None:
+            taken_step_ids = []
 
-        result: List[PipelineStep] = []
-
-        for step in steps:
+        if not isinstance(step, PipelineStep):
 
             module_type = step.get("module_type", None)
             if not module_type:
@@ -73,7 +82,12 @@ class PipelineStep(Manifest):
 
             module_config = step.get("module_config", {})
 
+            src_manifest = Manifest(
+                module_type=module_type, module_config=module_config
+            )
+
             if module_type not in kiara.module_type_names:
+
                 if module_type in module_map.keys():
                     resolved_module_type = module_map[module_type]["module_type"]
                     resolved_module_config = module_map[module_type]["module_config"]
@@ -81,6 +95,17 @@ class PipelineStep(Manifest):
                         module_or_operation=resolved_module_type,
                         config=resolved_module_config,
                     )
+                elif (
+                    kiara.operation_registry.is_initialized
+                    and module_type in kiara.operation_registry.operation_ids
+                ):
+                    op = kiara.operation_registry.operations[module_type]
+                    resolved_module_type = op.module_type
+                    resolved_module_config = op.module_config
+                    manifest = kiara.create_manifest(
+                        module_or_operation=resolved_module_type,
+                        config=resolved_module_config,
+                    )
                 else:
                     raise Exception(f"Can't resolve module type: {module_type}")
             else:
@@ -94,7 +119,18 @@ class PipelineStep(Manifest):
 
             step_id = step.get("step_id", None)
             if not step_id:
-                raise ValueError("Can't create step, no 'step_id' specified.")
+                if not auto_step_id:
+                    raise ValueError("Can't create step, no 'step_id' specified.")
+                else:
+                    step_id = find_free_id(
+                        slugify(manifest.module_type, separator="_"),
+                        current_ids=taken_step_ids,
+                    )
+
+            if step_id in taken_step_ids:
+                raise ValueError(f"Can't create step: duplicate step id '{step_id}'.")
+
+            taken_step_ids.append(step_id)
 
             input_links = {}
             for input_field, sources in step.get("input_links", {}).items():
@@ -102,15 +138,50 @@ class PipelineStep(Manifest):
                     sources = [sources]
                 input_links[input_field] = sources
 
+            doc = step.get("doc", None)
+
             # TODO: do we really need the deepcopy here?
             _s = PipelineStep(
                 step_id=step_id,
                 module_type=resolved_module_type,
                 module_config=dict(resolved_module_config),
                 input_links=input_links,  # type: ignore
-                module_details=KiaraModuleClass.from_module(module=module),
+                doc=doc,
+                module_details=KiaraModuleInstance.from_module(module=module),
+                manifest_src=src_manifest,
             )
             _s._module = module
+        else:
+            _s = step
+
+        return _s
+
+    @classmethod
+    def create_steps(
+        cls,
+        *steps: Union["PipelineStep", Mapping[str, Any]],
+        kiara: "Kiara",
+        module_map: Union[Mapping[str, Any], None] = None,
+        auto_step_ids: bool = False,
+    ) -> List["PipelineStep"]:
+
+        if module_map is None:
+            module_map = {}
+        else:
+            module_map = dict(module_map)
+
+        result: List[PipelineStep] = []
+
+        step_ids: List[str] = []
+        for step in steps:
+
+            _s = cls.create_step(
+                step=step,
+                kiara=kiara,
+                module_map=module_map,
+                auto_step_id=auto_step_ids,
+                taken_step_ids=step_ids,
+            )
             result.append(_s)
 
         return result
@@ -132,6 +203,9 @@ class PipelineStep(Manifest):
     module_config: Dict[str, Any] = Field(
         description="The module config.", default_factory=dict
     )
+    manifest_src: Manifest = Field(
+        description="The original manfifest provided by the user."
+    )
     # required: bool = Field(
     #     description="Whether this step is required within the workflow.\n\nIn some cases, when none of the pipeline outputs have a required input that connects to a step, then it is not necessary for this step to have been executed, even if it is placed before a step in the execution hierarchy. This also means that the pipeline inputs that are connected to this step might not be required.",
     #     default=True,
@@ -141,13 +215,16 @@ class PipelineStep(Manifest):
     #     description="The stage number this step is executed within the pipeline.",
     # )
     input_links: Mapping[str, List[StepValueAddress]] = Field(
-        description="The links that connect to inputs of the module.",
-        default_factory=list,
+        description="The links that connect to inputs of the module. Keys are field names, value(s) are connected outputs.",
+        default_factory=dict,
     )
-    module_details: KiaraModuleClass = Field(
+    module_details: KiaraModuleInstance = Field(
         description="The class of the underlying module."
     )
-    _module: Optional["KiaraModule"] = PrivateAttr(default=None)
+    doc: DocumentationMetadataModel = Field(
+        description="A description what this step does."
+    )
+    _module: Union["KiaraModule", None] = PrivateAttr(default=None)
 
     @root_validator(pre=True)
     def create_step_id(cls, values):
@@ -159,6 +236,11 @@ class PipelineStep(Manifest):
 
         return values
 
+    @validator("doc", pre=True)
+    def validate_doc(cls, value):
+        doc = DocumentationMetadataModel.create(value)
+        return doc
+
     @validator("step_id")
     def ensure_valid_id(cls, v):
 
@@ -207,6 +289,73 @@ class PipelineStep(Manifest):
     def __str__(self):
         return f"step: {self.step_id} (module: {self.module_type})"
 
+    def create_renderable(self, **config: Any) -> RenderableType:
+
+        in_panel = config.get("in_panel", None)
+        if in_panel is None:
+            if is_jupyter():
+                in_panel = True
+            else:
+                in_panel = False
+
+        table = Table(show_header=False, box=box.SIMPLE)
+        table.add_column("key", style="i")
+        table.add_column("value")
+
+        if self.doc.is_set:
+            table.add_row("", Markdown(self.doc.full_doc))
+        table.add_row("step_id", self.step_id)
+        table.add_row("module type", self.module_type)
+        if not module_config_is_empty(self.module_config):
+            mc = dict(self.module_config)
+            if not mc.get("defaults", None):
+                mc.pop("defaults", None)
+            if not mc.get("constants", None):
+                mc.pop("constants", None)
+
+            if "steps" in mc.keys():
+                _steps = []
+                for step in mc["steps"]:
+                    _s = {
+                        "step_id": step["step_id"],
+                        "module_type": step["manifest_src"]["module_type"],
+                    }
+                    sc = step.get("module_config", {})
+                    if sc:
+                        _s["module_config"] = sc
+                    _steps.append(_s)
+                mc["steps"] = _steps
+            config_str = orjson_dumps(mc, option=orjson.OPT_INDENT_2)
+            table.add_row(
+                "module_config",
+                Syntax(config_str, "json", background_color="default", theme="default"),
+            )
+        module_doc = DocumentationMetadataModel.from_class_doc(self.module.__class__)
+        table.add_row("module doc", Markdown(module_doc.full_doc))
+        inputs = create_table_from_field_schemas(
+            _add_default=True,
+            _add_required=True,
+            _show_header=True,
+            fields={
+                f"{self.step_id}.{k}": v for k, v in self.module.inputs_schema.items()
+            },
+        )
+        table.add_row("inputs", inputs)
+        outputs = create_table_from_field_schemas(
+            _add_default=False,
+            _add_required=False,
+            _show_header=True,
+            fields={
+                f"{self.step_id}.{k}": v for k, v in self.module.outputs_schema.items()
+            },
+        )
+        table.add_row("outputs", outputs)
+
+        if in_panel:
+            return Panel(table, title=f"Step: {self.step_id}", title_align="left")
+        else:
+            return table
+
 
 def create_input_alias_map(steps: Iterable[PipelineStep]) -> Dict[str, str]:
 
@@ -310,7 +459,7 @@ class PipelineConfig(KiaraModuleConfig):
     def from_file(
         cls,
         path: str,
-        kiara: Optional["Kiara"] = None,
+        kiara: Union["Kiara", None] = None,
         # module_map: Optional[Mapping[str, Any]] = None,
     ):
 
@@ -334,8 +483,10 @@ class PipelineConfig(KiaraModuleConfig):
         cls,
         pipeline_name: str,
         data: Mapping[str, Any],
-        kiara: Optional["Kiara"] = None,
-        execution_context: Optional[ExecutionContext] = None,
+        kiara: Union["Kiara", None] = None,
+        module_map: Union[Mapping[str, Any], None] = None,
+        execution_context: Union[ExecutionContext, None] = None,
+        auto_step_ids: bool = False,
     ):
 
         if kiara is None:
@@ -353,7 +504,9 @@ class PipelineConfig(KiaraModuleConfig):
             pipeline_name=pipeline_name,
             data=data,
             kiara=kiara,
+            module_map=module_map,
             execution_context=execution_context,
+            auto_step_ids=auto_step_ids,
         )
         return config
 
@@ -363,8 +516,9 @@ class PipelineConfig(KiaraModuleConfig):
         pipeline_name: str,
         data: Mapping[str, Any],
         kiara: "Kiara",
-        module_map: Optional[Mapping[str, Any]] = None,
-        execution_context: Optional[ExecutionContext] = None,
+        module_map: Union[Mapping[str, Any], None] = None,
+        execution_context: Union[ExecutionContext, None] = None,
+        auto_step_ids: bool = False,
     ):
 
         if execution_context is None:
@@ -373,8 +527,10 @@ class PipelineConfig(KiaraModuleConfig):
         repl_dict = execution_context.dict()
 
         data = dict(data)
-        steps = data.pop("steps")
-        steps = PipelineStep.create_steps(*steps, kiara=kiara, module_map=module_map)
+        _steps = data.pop("steps")
+        steps = PipelineStep.create_steps(
+            *_steps, kiara=kiara, module_map=module_map, auto_step_ids=auto_step_ids
+        )
         data["steps"] = steps
         if not data.get("input_aliases"):
             data["input_aliases"] = create_input_alias_map(steps)
@@ -409,25 +565,26 @@ class PipelineConfig(KiaraModuleConfig):
         description="A list of steps/modules of this pipeline, and their connections.",
     )
     input_aliases: Dict[str, str] = Field(
-        description="A map of input aliases, with the calculated (<step_id>__<input_name> -- double underscore!) name as key, and a string (the resulting workflow input alias) as value. Check the documentation for the config class for which marker strings can be used to automatically create this map if possible.",
+        description="A map of input aliases, with the location of the input (in the format '[step_id].[input_field]') as key, and the pipeline input field name as value.",
     )
     output_aliases: Dict[str, str] = Field(
-        description="A map of output aliases, with the calculated (<step_id>__<output_name> -- double underscore!) name as key, and a string (the resulting workflow output alias) as value.  Check the documentation for the config class for which marker strings can be used to automatically create this map if possible.",
+        description="A map of output aliases, with the location of the output (in the format '[step_id].[output_field]') as key, and the pipeline output field name as value.",
     )
-    doc: str = Field(
-        default="-- n/a --", description="Documentation about what the pipeline does."
+    doc: DocumentationMetadataModel = Field(
+        default="-- n/a --", description="Documentation about what the pipeline does."  # type: ignore
     )
     context: Dict[str, Any] = Field(
         default_factory=dict, description="Metadata for this workflow."
     )
-    _structure: Optional["PipelineStructure"] = PrivateAttr(default=None)
+    _structure: Union["PipelineStructure", None] = PrivateAttr(default=None)
+
+    @validator("doc", pre=True)
+    def validate_doc(cls, value):
+        return DocumentationMetadataModel.create(value)
 
     @validator("steps", pre=True)
     def _validate_steps(cls, v):
 
-        if not v:
-            raise ValueError(f"Invalid type for 'steps' value: {type(v)}")
-
         steps = []
         for step in v:
             if not step:
@@ -435,7 +592,7 @@ class PipelineConfig(KiaraModuleConfig):
             if isinstance(step, PipelineStep):
                 steps.append(step)
             elif isinstance(step, Mapping):
-                steps.append(PipelineStep(**step))
+                steps.append(PipelineStep(**step))  # type: ignore
             else:
                 raise TypeError(step)
         return steps
@@ -448,12 +605,22 @@ class PipelineConfig(KiaraModuleConfig):
 
         from kiara.models.module.pipeline.structure import PipelineStructure
 
-        self._structure = PipelineStructure(pipeline_config=self)
+        self._structure = PipelineStructure(pipeline_config=self)  # type: ignore
         return self._structure
 
     def create_renderable(self, **config: Any) -> RenderableType:
 
-        return create_table_from_model_object(self, exclude_fields={"steps"})
+        table = Table(show_header=False, box=box.SIMPLE)
+        table.add_column("key", style="i")
+        table.add_column("value")
+
+        table.add_row("doc", self.doc.full_doc)
+        table.add_row("structure", self.structure)
+        return table
+
+        # return create_table_from_model_object(self, exclude_fields={"steps"})
+
+        # return create_table_from_model_object(self)
 
     # def create_input_alias_map(self) -> Dict[str, str]:
     #
