@@ -6,16 +6,20 @@
 
 import sys
 from functools import lru_cache
-from importlib_metadata import distribution, packages_distributions
 from pydantic import BaseModel, Field
 from rich import box
 from rich.console import RenderableType
 from rich.table import Table
-from typing import Any, Dict, List, Literal, Mapping, Optional
+from typing import Any, Dict, List, Literal, Mapping, Union
 
 from kiara.models.runtime_environment import RuntimeEnvironment
 from kiara.utils.output import extract_renderable
 
+try:
+    from importlib.metadata import distribution, packages_distributions  # type: ignore
+except Exception:
+    from importlib_metadata import distribution, packages_distributions  # type:ignore
+
 
 class PythonPackage(BaseModel):
 
@@ -44,7 +48,7 @@ class PythonRuntimeEnvironment(RuntimeEnvironment):
 
     def _create_renderable_for_field(
         self, field_name: str, for_summary: bool = False
-    ) -> Optional[RenderableType]:
+    ) -> Union[RenderableType, None]:
 
         if field_name != "packages":
             return extract_renderable(getattr(self, field_name))
@@ -112,7 +116,7 @@ class KiaraPluginsRuntimeEnvironment(RuntimeEnvironment):
 
     def _create_renderable_for_field(
         self, field_name: str, for_summary: bool = False
-    ) -> Optional[RenderableType]:
+    ) -> Union[RenderableType, None]:
 
         if field_name != "packages":
             return extract_renderable(getattr(self, field_name))
