@@ -5,21 +5,23 @@
 #
 #  Mozilla Public License, version 2.0 (see LICENSE or https://www.mozilla.org/en-US/MPL/2.0/)
 
-from typing import TYPE_CHECKING, Any, Mapping, Optional, Union
+from typing import TYPE_CHECKING, Any, Mapping, Union
 
 from kiara.models.module.jobs import JobLog
 from kiara.models.module.pipeline import PipelineConfig
 from kiara.models.module.pipeline.controller import SinglePipelineBatchController
 from kiara.models.module.pipeline.pipeline import Pipeline
-from kiara.models.module.pipeline.structure import PipelineStructure
 from kiara.models.values.value import ValueMap, ValueMapWritable
-from kiara.modules import KIARA_CONFIG, KiaraModule, ValueSetSchema
+from kiara.modules import KIARA_CONFIG, KiaraModule, ValueMapSchema
 
 if TYPE_CHECKING:
+    from kiara.models.module.operation import Operation
+    from kiara.models.module.pipeline.structure import PipelineStructure
     from kiara.registries.jobs import JobRegistry
 
 
 class PipelineModule(KiaraModule):
+    """A utility module to run multiple connected inner-modules and present it as its own entity."""
 
     _config_cls = PipelineConfig
     _module_type_name = "pipeline"
@@ -28,7 +30,7 @@ class PipelineModule(KiaraModule):
         self,
         module_config: Union[None, KIARA_CONFIG, Mapping[str, Any]] = None,
     ):
-        self._job_registry: Optional[JobRegistry] = None
+        self._job_registry: Union[JobRegistry, None] = None
         super().__init__(module_config=module_config)
 
     @classmethod
@@ -38,9 +40,20 @@ class PipelineModule(KiaraModule):
     def _set_job_registry(self, job_registry: "JobRegistry"):
         self._job_registry = job_registry
 
+    @property
+    def operation(self) -> "Operation":
+
+        if self._operation is not None:
+            return self._operation
+
+        from kiara.models.module.operation import Operation
+
+        self._operation = Operation.create_from_module(self, doc=self.config.doc)
+        return self._operation
+
     def create_inputs_schema(
         self,
-    ) -> ValueSetSchema:
+    ) -> ValueMapSchema:
 
         pipeline_structure: PipelineStructure = self.config.structure
         inputs_schema = pipeline_structure.pipeline_inputs_schema
@@ -48,7 +61,7 @@ class PipelineModule(KiaraModule):
 
     def create_outputs_schema(
         self,
-    ) -> ValueSetSchema:
+    ) -> ValueMapSchema:
         pipeline_structure: PipelineStructure = self.config.structure
         return pipeline_structure.pipeline_outputs_schema
 
@@ -59,7 +72,6 @@ class PipelineModule(KiaraModule):
         pipeline = Pipeline(structure=pipeline_structure, kiara=outputs._kiara)
 
         assert self._job_registry is not None
-
         controller = SinglePipelineBatchController(
             pipeline=pipeline, job_registry=self._job_registry
         )
