@@ -8,13 +8,18 @@
 import abc
 import orjson
 from pydantic import Field, validator
-from typing import Any, Mapping, Optional, Type, Union
+from typing import Any, Mapping, Type, Union
 
 from kiara.models import KiaraModel
 from kiara.models.module import KiaraModuleConfig
 from kiara.models.values.value import SerializedData, Value, ValueMap
 from kiara.models.values.value_schema import ValueSchema
-from kiara.modules import KiaraModule, ValueSetSchema
+from kiara.modules import (
+    DEFAULT_IDEMPOTENT_INTERNAL_MODULE_CHARACTERISTICS,
+    KiaraModule,
+    ModuleCharacteristics,
+    ValueMapSchema,
+)
 from kiara.registries.models import ModelRegistry
 
 
@@ -84,6 +89,9 @@ class DeserializeValueModule(KiaraModule):
             },
         }
 
+    def _retrieve_module_characteristics(self) -> ModuleCharacteristics:
+        return DEFAULT_IDEMPOTENT_INTERNAL_MODULE_CHARACTERISTICS
+
     def process(self, inputs: ValueMap, outputs: ValueMap) -> None:
 
         value_type = self.get_config_value("value_type")
@@ -226,7 +234,7 @@ class LoadInternalModel(DeserializeValueModule):
 
 class DeserializeJsonConfig(KiaraModuleConfig):
 
-    result_path: Optional[str] = Field(
+    result_path: Union[str, None] = Field(
         description="The path of the result dictionary to return.", default="data"
     )
 
@@ -236,9 +244,12 @@ class DeserializeFromJsonModule(KiaraModule):
     _module_type_name: str = "deserialize.from_json"
     _config_cls = DeserializeJsonConfig
 
+    def _retrieve_module_characteristics(self) -> ModuleCharacteristics:
+        return DEFAULT_IDEMPOTENT_INTERNAL_MODULE_CHARACTERISTICS
+
     def create_inputs_schema(
         self,
-    ) -> ValueSetSchema:
+    ) -> ValueMapSchema:
 
         return {
             "value": {
@@ -249,7 +260,7 @@ class DeserializeFromJsonModule(KiaraModule):
 
     def create_outputs_schema(
         self,
-    ) -> ValueSetSchema:
+    ) -> ValueMapSchema:
 
         return {
             "python_object": {
@@ -272,144 +283,3 @@ class DeserializeFromJsonModule(KiaraModule):
         deserialized = orjson.loads(_chunk)
 
         outputs.set_value("python_object", deserialized)
-
-
-# class SerializeValueModule(KiaraModule):
-#
-#     _config_cls = SerializeConfig
-#
-#     @classmethod
-#     def retrieve_supported_source_types(cls) -> Iterable[str]:
-#
-#         result = []
-#         for attr in dir(cls):
-#             if attr.startswith("from__"):
-#                 result.append(attr[6:])
-#         return result
-#
-#     def create_inputs_schema(
-#         self,
-#     ) -> Mapping[str, Union[ValueSchema, Mapping[str, Any]]]:
-#
-#         source_type = self.get_config_value("value_type")
-#
-#         return {
-#             source_type: {"type": source_type, "doc": "The value to serialize."},
-#             "serialization_config": {
-#                 "type": "any",
-#                 "doc": "Serialization-format specific configuration.",
-#                 "optional": True,
-#             },
-#         }
-#
-#     def create_outputs_schema(
-#         self,
-#     ) -> Mapping[str, Union[ValueSchema, Mapping[str, Any]]]:
-#
-#         return {
-#             "serialized_value": {
-#                 "type": SERIALIZED_DATA_TYPE_NAME,
-#                 "type_config": {"serialization_profile": self.get_serialization_profile_name()},
-#                 "doc": "The value in serialized form.",
-#             }
-#         }
-#
-#     @abc.abstractmethod
-#     def get_serialization_profile_name(self) -> str:
-#         pass
-#
-#     def process(self, inputs: ValueMap, outputs: ValueMap) -> None:
-#
-#         source_type = self.get_config_value("value_type")
-#         value = inputs.get_value_obj(source_type)
-#         config = inputs.get_value_obj("serialization_config")
-#
-#         func_name = f"from__{source_type}"
-#         func = getattr(self, func_name)
-#
-#         if config.is_set:
-#             _config = config.data
-#         else:
-#             _config = {}
-#
-#         result: Union[Mapping, SerializedValue] = func(value=value, config=_config)
-#         outputs.set_value("serialized_value", result)
-#
-
-#
-#
-# class PickleModule(SerializeValueModule):
-#
-#     _module_type_name = "value.serialize.pickle"
-#
-#     def get_serialization_profile_name(self):
-#         return "pickle"
-#
-#     def from__any(self, value: Value, config: Dict[str, Any]) -> SerializedValue:
-#         """Serialize any Python object into bytes using 'pickle'."""
-#
-#         try:
-#             import pickle5 as pickle
-#         except:
-#             import pickle
-#
-#         pickled = pickle.dumps(value.data, protocol=5)
-#         data = {"python_object": {
-#             "type": "chunk",
-#             "chunk": pickled
-#         }}
-#
-#         serialized_data = {
-#             "data_type": value.value_schema.type,
-#             "data_type_config": value.value_schema.type_config,
-#             "serialization_profile": self.get_serialization_profile_name(),
-#             "environment": {},
-#             "data": data
-#         }
-#
-#         serialized = SerializedValue(**serialized_data)
-#
-#         return serialized
-#
-#
-# class SerializeInternalModelModule(SerializeValueModule):
-#     """Persist internally used model data."""
-#
-#     _module_type_name = "internal_model.serialize.as.json"
-#
-#     def get_serialization_profile_name(self) -> str:
-#         return "json"
-#
-#     def from__internal_model(
-#         self, value: Value, config: Mapping[str, Any]
-#     ) -> SerializedValue:
-#         """Persist internally used model data as a json file."""
-#
-#         try:
-#             value_metadata: KiaraModel = value.data
-#             python_class = PythonClass.from_class(value_metadata.__class__)
-#
-#             data = {
-#                 "internal_model": {
-#                     "type": "inline",
-#                     "inline_data": {
-#                         "data": value_metadata.dict(),
-#                         "python_class": python_class.dict()
-#                     }
-#                 }
-#             }
-#
-#             serialized_data = {
-#                 "data_type": value.data_type_name,
-#                 "data_type_config": value.data_type_config,
-#                 "serialization_profile": self.get_serialization_profile_name(),
-#                 "environment": {},
-#                 "data": data
-#             }
-#
-#             serialized = SerializedValue(**serialized_data)
-#             return serialized
-#         except Exception as e:
-#             raise KiaraProcessingException(
-#                 f"Can't serialize value of type '{value.value_schema.type}' to json: {e}."
-#             )
