@@ -20,6 +20,7 @@ from typing import (
 
 from kiara.models.events.alias_registry import AliasArchiveAddedEvent
 from kiara.registries import BaseArchive
+from kiara.registries.data import ValueLink
 
 if TYPE_CHECKING:
     from kiara.context import Kiara
@@ -89,7 +90,7 @@ class AliasRegistry(object):
     def register_archive(
         self,
         archive: AliasArchive,
-        alias: str = None,
+        alias: Union[str, None] = None,
         set_as_default_store: Union[bool, None] = None,
     ):
 
@@ -225,10 +226,33 @@ class AliasRegistry(object):
         # TODO: cache this?
         return v_id
 
+    def _get_value_id(self, value_id: Union[uuid.UUID, ValueLink, str]) -> uuid.UUID:
+
+        if not isinstance(value_id, uuid.UUID):
+            # fallbacks for common mistakes, this should error out if not a Value or string.
+            if hasattr(value_id, "value_id"):
+                _value_id: Union[uuid.UUID, str] = value_id.value_id  # type: ignore
+                if isinstance(_value_id, str):
+                    _value_id = uuid.UUID(_value_id)
+            else:
+                _value_id = uuid.UUID(
+                    value_id  # type: ignore
+                )  # this should fail if not string or wrong string format
+        else:
+            _value_id = value_id
+
+        if not _value_id:
+            raise Exception(f"Could not resolve id: {value_id}")
+        return _value_id
+
     def find_aliases_for_value_id(
-        self, value_id: uuid.UUID, search_dynamic_archives: bool = False
+        self,
+        value_id: Union[uuid.UUID, ValueLink, str],
+        search_dynamic_archives: bool = False,
     ) -> Set[str]:
 
+        value_id = self._get_value_id(value_id=value_id)
+
         aliases = set([a.full_alias for a in self.aliases_by_id.get(value_id, [])])
 
         if search_dynamic_archives:
@@ -241,8 +265,11 @@ class AliasRegistry(object):
 
         return aliases
 
-    def register_aliases(self, value_id: uuid.UUID, *aliases: str):
+    def register_aliases(
+        self, value_id: Union[uuid.UUID, ValueLink, str], *aliases: str
+    ):
 
+        value_id = self._get_value_id(value_id=value_id)
         store_name = self.default_alias_store
         store: AliasStore = self.get_archive(archive_id=store_name)  # type: ignore
         self.aliases  # noqu
