@@ -13,12 +13,13 @@ from typing import Mapping, Set, Union
 
 from kiara.registries import ARCHIVE_CONFIG_CLS, FileSystemArchiveConfig
 from kiara.registries.aliases import AliasArchive, AliasStore
+from kiara.utils.windows import fix_windows_longpath
 
 
 class FileSystemAliasArchive(AliasArchive):
 
     _archive_type_name = "filesystem_alias_archive"
-    _config_cls = FileSystemArchiveConfig
+    _config_cls = FileSystemArchiveConfig  # type: ignore
 
     def __init__(self, archive_id: uuid.UUID, config: ARCHIVE_CONFIG_CLS):
 
@@ -33,6 +34,7 @@ class FileSystemAliasArchive(AliasArchive):
             return self._base_path
 
         self._base_path = Path(self.config.archive_path).absolute()  # type: ignore
+        self._base_path = fix_windows_longpath(self._base_path)
         self._base_path.mkdir(parents=True, exist_ok=True)
         return self._base_path
 
