@@ -9,6 +9,7 @@ from kiara.exceptions import NoSuchWorkflowException
 from kiara.models.workflow import WorkflowMetadata, WorkflowState
 from kiara.registries import ARCHIVE_CONFIG_CLS, FileSystemArchiveConfig
 from kiara.registries.workflows import WorkflowArchive, WorkflowStore
+from kiara.utils.windows import fix_windows_longpath
 
 
 class FileSystemWorkflowArchive(WorkflowArchive):
@@ -30,6 +31,7 @@ class FileSystemWorkflowArchive(WorkflowArchive):
             return self._base_path
 
         self._base_path = Path(self.config.archive_path).absolute()  # type: ignore
+        self._base_path = fix_windows_longpath(self._base_path)
         self._base_path.mkdir(parents=True, exist_ok=True)
         return self._base_path
 
