@@ -34,7 +34,6 @@ from kiara.utils.json import orjson_dumps
 
 if TYPE_CHECKING:
     from pyarrow import Table as ArrowTable
-    from sqlalchemy.engine import Engine
 
     from kiara.models.events.pipeline import PipelineState
     from kiara.models.module.pipeline import PipelineStructure
@@ -81,7 +80,7 @@ class OutputDetails(BaseModel):
     )
 
     @root_validator(pre=True)
-    def _set_defaults(cls, values):
+    def _set_defaults(cls, values) -> Dict[str, Any]:
 
         target: str = values.pop("target", "terminal")
         format: str = values.pop("format", None)
@@ -103,7 +102,7 @@ class OutputDetails(BaseModel):
 
 
 class TabularWrap(ABC):
-    def __init__(self):
+    def __init__(self) -> None:
         self._num_rows: Union[int, None] = None
         self._column_names: Union[Iterable[str], None] = None
         self._force_single_line: bool = True
@@ -394,72 +393,6 @@ class DictTabularWrap(TabularWrap):
         return DictTabularWrap(result)
 
 
-class SqliteTabularWrap(TabularWrap):
-    def __init__(self, engine: "Engine", table_name: str):
-        self._engine: Engine = engine
-        self._table_name: str = table_name
-        super().__init__()
-
-    def retrieve_number_of_rows(self) -> int:
-
-        from sqlalchemy import text
-
-        with self._engine.connect() as con:
-            result = con.execute(text(f"SELECT count(*) from {self._table_name}"))
-            num_rows = result.fetchone()[0]
-
-        return num_rows
-
-    def retrieve_column_names(self) -> Iterable[str]:
-
-        from sqlalchemy import inspect
-
-        engine = self._engine
-        inspector = inspect(engine)
-        columns = inspector.get_columns(self._table_name)
-        result = [column["name"] for column in columns]
-        return result
-
-    def slice(self, offset: int = 0, length: Union[int, None] = None) -> "TabularWrap":
-
-        from sqlalchemy import text
-
-        query = f"SELECT * FROM {self._table_name}"
-        if length:
-            query = f"{query} LIMIT {length}"
-        else:
-            query = f"{query} LIMIT {self.num_rows}"
-        if offset > 0:
-            query = f"{query} OFFSET {offset}"
-        with self._engine.connect() as con:
-            result = con.execute(text(query))
-            result_dict: Dict[str, List[Any]] = {}
-            for cn in self.column_names:
-                result_dict[cn] = []
-            for r in result:
-                for i, cn in enumerate(self.column_names):
-                    result_dict[cn].append(r[i])
-
-        return DictTabularWrap(result_dict)
-
-    def to_pydict(self) -> Mapping:
-
-        from sqlalchemy import text
-
-        query = f"SELECT * FROM {self._table_name}"
-
-        with self._engine.connect() as con:
-            result = con.execute(text(query))
-            result_dict: Dict[str, List[Any]] = {}
-            for cn in self.column_names:
-                result_dict[cn] = []
-            for r in result:
-                for i, cn in enumerate(self.column_names):
-                    result_dict[cn].append(r[i])
-
-        return result_dict
-
-
 def create_table_from_base_model_cls(model_cls: Type[BaseModel]):
 
     table = RichTable(box=box.SIMPLE, show_lines=True)
